@@ -8,7 +8,7 @@ from .general_tools import fetch_credentials, parse_remote_uri
 
 # Logging Configuration
 logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
+logger.setLevel(logging.WARNING)
 
 formatter = logging.Formatter("%(asctime)s:%(name)s:%(levelname)s: %(message)s")
 
